@@ -36,6 +36,8 @@ import pymc as pm
 from pymc.distributions.dist_math import (
     betaln,
     binomln,
+    check_icdf_parameters,
+    check_icdf_value,
     check_parameters,
     factln,
     log_diff_normal_cdf,
@@ -820,7 +822,14 @@ class Geometric(Discrete):
         )
 
     def icdf(value, p):
-        return at.ceil(at.log1p(-value) / at.log1p(-p)).astype("int64")
+        res = at.ceil(at.log1p(-value) / at.log1p(-p)).astype("int64")
+        res = check_icdf_value(res, value)
+        return check_icdf_parameters(
+            res,
+            0 <= p,
+            p <= 1,
+            msg="0 <= p <= 1",
+        )
 
 
 class HyperGeometric(Discrete):
@@ -1454,7 +1463,7 @@ class ZeroInflatedNegativeBinomial:
     psi : tensor_like of float
         Expected proportion of NegativeBinomial variates (0 < psi < 1)
     mu : tensor_like of float
-        Poission distribution parameter (mu > 0).
+        Poisson distribution parameter (mu > 0).
     alpha : tensor_like of float
         Gamma distribution parameter (alpha > 0).
     p : tensor_like of float
