@@ -42,7 +42,6 @@ pymc/model_graph.py
 pymc/printing.py
 pymc/pytensorf.py
 pymc/sampling/jax.py
-pymc/variational/approximations.py
 pymc/variational/opvi.py
 """
 
@@ -159,7 +158,7 @@ if __name__ == "__main__":
     args, _ = parser.parse_known_args()
 
     cp = subprocess.run(
-        ["mypy", "--show-error-codes", "--exclude", "pymc/tests", "pymc"],
+        ["mypy", "--show-error-codes", "--exclude", "tests", "pymc"],
         capture_output=True,
     )
     output = cp.stdout.decode()
