@@ -43,6 +43,7 @@ from pymc.testing import (
     Runif,
     Unit,
     assert_moment_is_expected,
+    check_icdf,
     check_logcdf,
     check_logp,
     continuous_random_tester,
@@ -159,14 +160,6 @@ def laplace_asymmetric_logpdf(value, kappa, b, mu):
     return lPx
 
 
-def beta_mu_sigma(value, mu, sigma):
-    kappa = mu * (1 - mu) / sigma**2 - 1
-    if kappa > 0:
-        return st.beta.logpdf(value, mu * kappa, (1 - mu) * kappa)
-    else:
-        return -np.inf
-
-
 class TestMatchesScipy:
     def test_uniform(self):
         check_logp(
@@ -278,6 +271,11 @@ class TestMatchesScipy:
             lambda value, mu, sigma: st.norm.logcdf(value, mu, sigma),
             decimal=select_by_precision(float64=6, float32=1),
         )
+        check_icdf(
+            pm.Normal,
+            {"mu": R, "sigma": Rplus},
+            lambda q, mu, sigma: st.norm.ppf(q, mu, sigma),
+        )
 
     def test_half_normal(self):
         check_logp(
@@ -367,10 +365,18 @@ class TestMatchesScipy:
             {"alpha": Rplus, "beta": Rplus},
             lambda value, alpha, beta: st.beta.logpdf(value, alpha, beta),
         )
+
+        def beta_mu_sigma(value, mu, sigma):
+            kappa = mu * (1 - mu) / sigma**2 - 1
+            return st.beta.logpdf(value, mu * kappa, (1 - mu) * kappa)
+
+        # The mu/sigma parametrization is not always valid
+        safe_mu_domain = Domain([0, 0.3, 0.5, 0.8, 1])
+        safe_sigma_domain = Domain([0, 0.05, 0.1, np.inf])
         check_logp(
             pm.Beta,
             Unit,
-            {"mu": Unit, "sigma": Rplus},
+            {"mu": safe_mu_domain, "sigma": safe_sigma_domain},
             beta_mu_sigma,
         )
 
@@ -1503,6 +1509,10 @@ class TestMoments:
         with pm.Model() as model:
             pm.Rice("x", nu=nu, sigma=sigma, size=size)
 
+    @pytest.mark.skipif(
+        condition=_polyagamma_not_installed,
+        reason="`polyagamma package is not available/installed.",
+    )
     @pytest.mark.parametrize(
         "h, z, size, expected",
         [
@@ -2265,21 +2275,3 @@ class TestInterpolated(BaseTestDistributionRandom):
                     extra_args={"rng": pytensor.shared(rng)},
                     ref_rand=ref_rand,
                 )
-
-
-class TestICDF:
-    @pytest.mark.parametrize(
-        "dist_params, obs, size",
-        [
-            ((0, 1), np.array([-0.5, 0, 0.3, 0.5, 1, 1.5], dtype=np.float64), ()),
-            ((-1, 20), np.array([-0.5, 0, 0.3, 0.5, 1, 1.5], dtype=np.float64), ()),
-            ((-1, 20), np.array([-0.5, 0, 0.3, 0.5, 1, 1.5], dtype=np.float64), (2, 3)),
-        ],
-    )
-    def test_normal_icdf(self, dist_params, obs, size):
-        dist_params_at, obs_at, size_at = create_pytensor_params(dist_params, obs, size)
-        dist_params = dict(zip(dist_params_at, dist_params))
-
-        x = Normal.dist(*dist_params_at, size=size_at)
-
-        scipy_logprob_tester(x, obs, dist_params, test_fn=st.norm.ppf, test="icdf")
