@@ -51,6 +51,7 @@ from pymc.testing import (
     UnitSortedVector,
     Vector,
     assert_moment_is_expected,
+    check_icdf,
     check_logcdf,
     check_logp,
     check_selfconsistency_discrete_logcdf,
@@ -143,15 +144,14 @@ class TestMatchesScipy:
             Nat,
             {"p": Unit},
         )
+        check_icdf(
+            pm.Geometric,
+            {"p": Unit},
+            st.geom.ppf,
+        )
 
     def test_hypergeometric(self):
-        def modified_scipy_hypergeom_logpmf(value, N, k, n):
-            # Convert nan to -np.inf
-            original_res = st.hypergeom.logpmf(value, N, k, n)
-            return original_res if not np.isnan(original_res) else -np.inf
-
         def modified_scipy_hypergeom_logcdf(value, N, k, n):
-            # Convert nan to -np.inf
             original_res = st.hypergeom.logcdf(value, N, k, n)
 
             # Correct for scipy bug in logcdf method (see https://github.com/scipy/scipy/issues/13280)
@@ -160,24 +160,27 @@ class TestMatchesScipy:
                 if np.all(np.isnan(pmfs)):
                     original_res = np.nan
 
-            return original_res if not np.isnan(original_res) else -np.inf
+            return original_res
+
+        N_domain = Domain([0, 10, 20, 30, np.inf], dtype="int64")
+        n_domain = k_domain = Domain([0, 1, 2, 3, np.inf], dtype="int64")
 
         check_logp(
             pm.HyperGeometric,
             Nat,
-            {"N": NatSmall, "k": NatSmall, "n": NatSmall},
-            modified_scipy_hypergeom_logpmf,
+            {"N": N_domain, "k": k_domain, "n": n_domain},
+            lambda value, N, k, n: st.hypergeom.logpmf(value, N, k, n),
         )
         check_logcdf(
             pm.HyperGeometric,
             Nat,
-            {"N": NatSmall, "k": NatSmall, "n": NatSmall},
+            {"N": N_domain, "k": k_domain, "n": n_domain},
             modified_scipy_hypergeom_logcdf,
         )
         check_selfconsistency_discrete_logcdf(
             pm.HyperGeometric,
             Nat,
-            {"N": NatSmall, "k": NatSmall, "n": NatSmall},
+            {"N": N_domain, "k": k_domain, "n": n_domain},
         )
 
     @pytest.mark.xfail(
@@ -535,15 +538,17 @@ class TestMatchesScipy:
 
     @pytest.mark.parametrize("n", [2, 3, 4])
     def test_orderedlogistic(self, n):
-        with warnings.catch_warnings():
-            warnings.filterwarnings("ignore", "invalid value encountered in log", RuntimeWarning)
-            warnings.filterwarnings("ignore", "divide by zero encountered in log", RuntimeWarning)
-            check_logp(
-                pm.OrderedLogistic,
-                Domain(range(n), dtype="int64", edges=(None, None)),
-                {"eta": R, "cutpoints": Vector(R, n - 1)},
-                lambda value, eta, cutpoints: orderedlogistic_logpdf(value, eta, cutpoints),
-            )
+        cutpoints_domain = Vector(R, n - 1)
+        # Filter out invalid non-monotonic values
+        cutpoints_domain.vals = [v for v in cutpoints_domain.vals if np.all(np.diff(v) > 0)]
+        assert len(cutpoints_domain.vals) > 0
+
+        check_logp(
+            pm.OrderedLogistic,
+            Domain(range(n), dtype="int64", edges=(None, None)),
+            {"eta": R, "cutpoints": cutpoints_domain},
+            lambda value, eta, cutpoints: orderedlogistic_logpdf(value, eta, cutpoints),
+        )
 
     @pytest.mark.parametrize("n", [2, 3, 4])
     def test_orderedprobit(self, n):
@@ -1149,29 +1154,3 @@ class TestOrderedProbit(BaseTestDistributionRandom):
         )
         p = categorical.owner.inputs[3].eval()
         assert p.shape == expected
-
-
-class TestICDF:
-    @pytest.mark.parametrize(
-        "dist_params, obs, size",
-        [
-            ((0.1,), np.array([-0.5, 0, 0.1, 0.5, 0.9, 1.0, 1.5], dtype=np.int64), ()),
-            ((0.5,), np.array([-0.5, 0, 0.1, 0.5, 0.9, 1.0, 1.5], dtype=np.int64), (3, 2)),
-            (
-                (np.array([0.0, 0.2, 0.5, 1.0]),),
-                np.array([0.7, 0.7, 0.7, 0.7], dtype=np.int64),
-                (),
-            ),
-        ],
-    )
-    def test_geometric_icdf(self, dist_params, obs, size):
-        dist_params_at, obs_at, size_at = create_pytensor_params(dist_params, obs, size)
-        dist_params = dict(zip(dist_params_at, dist_params))
-
-        x = Geometric.dist(*dist_params_at, size=size_at)
-
-        def scipy_geom_icdf(value, p):
-            # Scipy ppf returns floats
-            return st.geom.ppf(value, p).astype(value.dtype)
-
-        scipy_logprob_tester(x, obs, dist_params, test_fn=scipy_geom_icdf, test="icdf")
